# Welcome to ver-to-semver 👋

![Version](https://img.shields.io/badge/version-0.1.2-blue.svg?cacheSeconds=2592000)
[![License: CC0--1.0](https://img.shields.io/badge/License-CC0--1.0-yellow.svg)](#)
[![Twitter: mbledkowski](https://img.shields.io/twitter/follow/mbledkowski.svg?style=social)](https://twitter.com/mbledkowski)

> Convert any version string to a semver string

### 🏠 [Homepage](https://github.com/mbledkowski/ver-to-semver)

## Install

```sh
pip install ver-to-semver
```

## Usage

```sh
from vertosemver import toSemVer
```

## Author

👤 **Maciej @mbledkowski Błędkowski**

- Website: mble.dk
- Twitter: [@mbledkowski](https://twitter.com/mbledkowski)
- Github: [@mbledkowski](https://github.com/mbledkowski)
- LinkedIn: [@mbled](https://linkedin.com/in/mbled)

## Show your support

Give a ⭐️ if this project helped you!

---

_This README was generated with ❤️ by [readme-md-generator](https://github.com/kefranabg/readme-md-generator)_
